@@ -1,5 +1,5 @@
 package Git::Repository::Plugin::AUTOLOAD;
-$Git::Repository::Plugin::AUTOLOAD::VERSION = '1.001';
+$Git::Repository::Plugin::AUTOLOAD::VERSION = '1.002';
 use warnings;
 use strict;
 use 5.006;
@@ -24,20 +24,14 @@ sub AUTOLOAD {
 
 1;
 
-# ABSTRACT: Git subcommands as Git::Repository methods
-
-
 __END__
+
 =pod
 
 =head1 NAME
 
 Git::Repository::Plugin::AUTOLOAD - Git subcommands as Git::Repository methods
 
-=head1 VERSION
-
-version 1.001
-
 =head1 SYNOPSIS
 
     use Git::Repository 'AUTOLOAD';
@@ -90,23 +84,13 @@ subprocess?), so that plugins adding new methods always take precedence.
 L<Git::Repository>,
 L<Git::Repository::Plugin>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Git-Repository-Plugin-AUTOLOAD or
-by email to bug-git-repository-plugin-autoload@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
-Philippe Bruhat (BooK) <book@cpan.org>
+Philippe Bruhat (BooK) <book@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2014 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2014-2016 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
@@ -114,4 +98,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
